===============================
Typed Environment Configuration
===============================


.. image:: https://img.shields.io/pypi/v/typed_environment_configuration.svg
        :target: https://pypi.python.org/pypi/typed_environment_configuration

.. image:: https://img.shields.io/circleci/project/github/springload/typed_environment_configuration.svg
        :target: https://circleci.com/gh/springload/typed_environment_configuration

.. image:: https://readthedocs.org/projects/typed-environment-configuration/badge/?version=latest
        :target: https://typed-environment-configuration.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Environment-based configuration

* Converts environmental variables fetched through os.environ to Python-native variables with specified types
* Free software: MIT license
* Documentation: https://typed-environment-configuration.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
